Index: trunk/MagicSoft/include-Classes/MMcFormat/MMcEvt.hxx
===================================================================
--- trunk/MagicSoft/include-Classes/MMcFormat/MMcEvt.hxx	(revision 617)
+++ trunk/MagicSoft/include-Classes/MMcFormat/MMcEvt.hxx	(revision 618)
@@ -9,10 +9,10 @@
 
 #include <iostream.h>
-#include "TObject.h"
+#include "MParContainer.h"
 
 
-class MMcEvt : public TObject {
+class MMcEvt : public MParContainer{
  private:
-  UShort_t usPartId;     // Type of particle
+  UShort_t fPartId;     // Type of particle
   Float_t fEnergy;       // Energy in GeV
 
@@ -25,10 +25,11 @@
   Float_t fImpact;       // impact parameter
 
-  UShort_t usPhotIni;      // Initial number of photons
-  UShort_t usPassPhotAtm;  // Passed atmosphere
-  UShort_t usPassPhotRef;  // Passed reflector
-  UShort_t usPassPhotCone; // Passed glas
-  UShort_t usPhotEl    ;   // Passed qe
- 
+  UInt_t fPhotIni;      // Initial number of photons
+  UInt_t fPassPhotAtm;  // Passed atmosphere
+  UInt_t fPassPhotRef;  // Passed reflector(reflectivity + effective area)
+  UInt_t fPassPhotCone; // Passed glas
+  UInt_t fPhotElfromShower;   // Passed qe coming from the shower
+  UInt_t fPhotElinCamera;     // usPhotElfromShower + mean of phe
+                               // from NSB
 
  public:
@@ -37,5 +38,5 @@
   MMcEvt( UShort_t, 
 	  Float_t, Float_t, Float_t, Float_t, Float_t, Float_t, Float_t,
-	  UShort_t, UShort_t, UShort_t, UShort_t, UShort_t ) ; 
+	  UInt_t, UInt_t, UInt_t, UInt_t, UInt_t, UInt_t ) ; 
   
   ~MMcEvt(); 
@@ -45,12 +46,10 @@
   void Fill( UShort_t, 
 	     Float_t, Float_t, Float_t, Float_t, Float_t, Float_t, Float_t,
-	     UShort_t, UShort_t, UShort_t, UShort_t, UShort_t ) ; 
+	     UInt_t, UInt_t, UInt_t, UInt_t, UInt_t, UInt_t ) ; 
 
 
   void Print(Option_t *);
 
-
-
-  Short_t GetPartId() const { return usPartId; }       //Get Type of particle
+  Short_t GetPartId() const { return fPartId; }       //Get Type of particle
   Float_t GetEnergy() const { return fEnergy; }        //Get Energy
 
@@ -63,41 +62,44 @@
   Float_t GetImpact() const { return fImpact;}         //Get impact parameter 
 
 /*    Short_t GetPhotIni() { return usPhotIni; }           //Get Initial photons */
 /*    Short_t GetPassPhotAtm() { return usPassPhotAtm;}    //Get Passed atmosphere */
 /*    Short_t GetPassPhotRef() { return usPassPhotRef; }   //Get Passed reflector */
 /*    Short_t GetPassPhotCone() { return usPassPhotCone; } //Get Passed glas */
 /*    Short_t GetPhotEl() { return usPhotEl; }             //Get Passed qe */
 
 
+  void SetPartId(Short_t PartId)
+  {fPartId=PartId;}             //Set Type of particle 
 
- /*  void SetPartId(Short_t PartId)  */
-/*     { usPartId=PartId; }             //Set Type of particle */
-/*   void SetEnergy(Float_t Energy)  */
-/*     { fEnergy=Energy; }              //Set Energy */
+  void SetEnergy(Float_t Energy)
+  { fEnergy=Energy; }              //Set Energy 
  
-/*   void SetTheta(Float_t Theta)  */
-/*     { fTheta=Theta; }                //Set Theta angle */
-/*   void SetPhi(Float_t Phi)  */
-/*     { fPhi=Phi;  }                   //Set Phi angle */
+  void SetTheta(Float_t Theta) 
+  { fTheta=Theta; }                //Set Theta angle 
+
+  void SetPhi(Float_t Phi) 
+  { fPhi=Phi;  }                   //Set Phi angle 
  
-/*    void SetCoreD(Float_t CoreD)  */
-/*      { fCoreD=CoreD; }                //Set Core d pos */
-/*    void SetCoreX(Float_t CoreX)  */
-/*      { fCoreX=CoreX; }                //Set Core x pos */
-/*    void SetCoreY(Float_t CoreY )  */
-/*      { fCoreY=CoreY; }                //Set Core y pos */
-/*    void SetImpact(Float_t Impact)  */
-/*      { fImpact=Impact;}               //Set impact parameter */
+  void SetCoreD(Float_t CoreD) 
+  { fCoreD=CoreD; }                //Set Core d pos
+
+  void SetCoreX(Float_t CoreX)
+  { fCoreX=CoreX; }                //Set Core x pos 
+
+  void SetCoreY(Float_t CoreY ) 
+  { fCoreY=CoreY; }                //Set Core y pos
+
+  void SetImpact(Float_t Impact) 
+  { fImpact=Impact;}               //Set impact parameter
   
 /*    void SetPhotIni(Short_t PhotIni)  */
-/*      { usPhotIni=PhotIni; }                 //Set Initial photons */
+/*      { fPhotIni=PhotIni; }                 //Set Initial photons */
 /*    void SetPassPhotAtm(Short_t PassPhotAtm)  */
-/*      { usPassPhotAtm=PassPhotAtm;}         //Set Passed atmosphere */
+/*      { fPassPhotAtm=PassPhotAtm;}         //Set Passed atmosphere */
 /*    void SetPassPhotRef(Short_t PassPhotRef)  */
-/*      { usPassPhotRef=PassPhotRef ; }       //Set Passed reflector */
+/*      { fPassPhotRef=PassPhotRef ; }       //Set Passed reflector */
 /*    void SetPassPhotCone(Short_t PhotCon)  */
-/*      { usPassPhotCone=PhotCon; }           //Set Passed glas */
-/*    void SetPhotEl(Short_t PhotEl)  */
-/*      { usPhotEl=PhotEl; }                  //Set Passed qe */
+/*      { fPassPhotCone=PhotCon; }           //Set Passed glas */
 
 
@@ -63,41 +62,44 @@
   Float_t GetImpact() const { return fImpact;}         //Get impact parameter 
 
-/*    Short_t GetPhotIni() { return usPhotIni; }           //Get Initial photons */
-/*    Short_t GetPassPhotAtm() { return usPassPhotAtm;}    //Get Passed atmosphere */
-/*    Short_t GetPassPhotRef() { return usPassPhotRef; }   //Get Passed reflector */
-/*    Short_t GetPassPhotCone() { return usPassPhotCone; } //Get Passed glas */
-/*    Short_t GetPhotEl() { return usPhotEl; }             //Get Passed qe */
+/*    UInt_t GetPhotIni() { return fPhotIni; }           //Get Initial photons */
+/*    UInt_t GetPassPhotAtm() { return fPassPhotAtm;}    //Get Passed atmosphere */
+/*    UInt_t GetPassPhotRef() { return fPassPhotRef; }   //Get Passed reflector */
+/*    UInt_t GetPassPhotCone() { return fPassPhotCone; } //Get Passed glas */
+/*    UInt_t GetPhotElfromShower() { return fPhotElfromShower; }             //Get Passed qe from shower*/
+/*    UInt_t GetPhotElinCamera() { return fPhotElinCamera; }             //Get Passed qe total*/
 
 
